@@ -3,15 +3,21 @@ import sys
 import json
 from time import sleep
 port = None
-
+host = None
 def send(data):
-  port = getPort()
-  requests.post('http://127.0.0.1:' + port + '/test', data = data)
+  port = get_port()
+  host = get_host()
+  if (host is None):
+    host = '127.0.0.1'
+  requests.post(host + ':' + port + '/test', data = data)
   
 def get_print():
   sleep(200)
-  port = getPort()
-  r = requests.get('http://127.0.0.1:' + port + '/test')
+  port = get_port()
+  host = get_host()
+  if (host is None):
+    host = '127.0.0.1'
+  r = requests.get(host + ':' + port + '/test')
   if r.status_code == 200:
     try:
       info = json.loads(r.text)
@@ -23,7 +29,7 @@ def get_print():
       return []
       
   
-def getPort():
+def get_port():
   global port
   if (port != None):
     return port
@@ -36,6 +42,19 @@ def getPort():
       match = True
   return port
 
+def get_host():
+  global host
+  if (host != None):
+    return host
+  match = False
+  for i in sys.argv:
+    if match:
+      host = i
+      break;
+    if i == '--host':
+      match = True
+  return host
+
 def pass_test(msg):
   send({ 'status': 0, 'msg': msg })
   
